import matplotlib.pyplot as plt
import numpy as np

plt.rcParams["font.family"] = "Ubuntu"
plt.rcParams["font.size"] = 12

T1=365.26#période de révolution de la Terre
k_sup=np.arange(1.8, 170, 0.1)#rapport des périodes sidérales (planètes supérieures)
T2_sup=k_sup*T1
T0_sup=T2_sup/(k_sup-1)
k_sup_inf=np.arange(0.1, 0.7, 0.01)
T2_inf=k_sup_inf*T1
T0_inf=T2_inf/(1-k_sup_inf)

fig=plt.figure(figsize=(9, 9))
ax=plt.subplot(111)

def Tsynodique(k_sup):
    Tsyn=T1*k_sup/(k_sup-1)
    return Tsyn

def Tsynodique_inf(k_sup):
    Tsyn=T1*k_sup/(1-k_sup)
    return Tsyn

plt.plot(T2_sup, T0_sup, alpha=0.7, zorder=0, label='planètes supérieures')#courbe
plt.xlabel("Période sidérale (jours terrestres)")
plt.ylabel("Période synodique (jours terrestres)")
plt.title("Périodes synodiques des planètes")
plt.xscale('log')

plt.plot(T2_inf, T0_inf, alpha=0.7, zorder=0, label='planètes inférieures')#courbe

ax.grid(which='minor', alpha=0.5)

ax.axhline(T1, ls='--', c='r', lw=.9)#ligne 365.24 jours
plt.text(530, T1, "%.2f j."%(T1), c='r', ha='right', va='center', fontsize=10, backgroundcolor='white')

T_siderales={#en années terrestres
'Mars': 1.8809, 
'Jupiter': 11.862, 
'Saturne': 29.457, 
'Uranus': 84.07, 
'Neptune': 164.81
}

T_siderales_inf={#en années terrestres
'Mercure': 0.24084, 
'Vénus': 0.61515, 
}

for N, T in enumerate(T_siderales):
    periode=list(T_siderales.values())[N]
    y=Tsynodique(periode)
    plt.scatter(periode*T1, y, c='C0')
    if y>500:
        angle=0
        ha='left'
    else:
        angle=90
        ha='center'
    plt.text(periode*T1, y, r"  "+T[:3]+" : %.1f j."%y, ha=ha, va='bottom', rotation=angle)

for N, T in enumerate(T_siderales_inf):
    periode=list(T_siderales_inf.values())[N]
    y=Tsynodique_inf(periode)
    plt.scatter(periode*T1, y, c='C1')
    plt.text(periode*T1, y, r"  "+T[:3]+" : %.1f j."%y, ha='left', va='bottom')

plt.grid()
plt.legend()
fig.savefig("PeriodesSynodiquesPlanetes.png", dpi=200)
plt.show()
